====
plinkio
====

Plinkio is a python module for reading and creating Plink genotype files. It
is written as a C-extension to efficiently parse and store these potentially
large files.

The lastest version can be installed by:

    pip install plinkio

Documentation is available at: `plinkio <https://github.com/fadern/libplinkio>`
